# norootforbuild

%if 0%{?suse_version} >= 1230
%bcond_without systemd
%else
%bcond_with    systemd
%endif

Name:           pgbouncer
Version:        1.9.0
Release:        1.10
#
Group:          Productivity/Databases/Servers
License:        ISC
#
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  pkgconfig(libcares)
BuildRequires:  libevent-devel
BuildRequires:  pam-devel
BuildRequires:  openssl-devel >= 1.0
%if %{with systemd}
BuildRequires:  pkgconfig(systemd)
%{?systemd_requires}
%endif
Recommends:     logrotate
#
%define pkg_group %{name}
%define pkg_user  %{name}
%define pkg_home  /var/run/%{name}
#
URL:            http://wiki.postgresql.org/wiki/PgBouncer
#               http://pgfoundry.org/projects/pgbouncer
Source:         http://pgfoundry.org/frs/download.php/3393/%{name}-%{version}.tar.gz
Source1:        %{name}.init
Source2:        %{name}.service
Source3:        %{name}.tmpfiles.d
Source4:        %{name}.logrotate
Patch:          just-reopen-logs-signal.patch
#
Summary:        Lightweight connection pooler for PostgreSQL
%description
Lightweight connection pooler for PostgreSQL.

%prep
%setup
%patch -p1

%build
%configure --bindir=%{_sbindir} --docdir=%{_defaultdocdir}/%{name} --with-root-ca-file=/etc/ssl/ca-bundle.pem --enable-evdns --with-pam
make %{?_smp_flags} V=1

%install
%makeinstall V=1
%{__install} -m 0644 \
    AUTHORS COPYRIGHT *.rst \
    doc/*.rst etc/mkauth.py \
  %{buildroot}%{_defaultdocdir}/%{name}/
#
install -d -m 0750 \
  %{buildroot}%{_sysconfdir}/%{name} \
%if ! %{with systemd}
  %{buildroot}%{pkg_home} \
%endif
  %{buildroot}%{_var}/log/%{name}
%{__install}    -m 0640 etc/*ini %{buildroot}%{_sysconfdir}/%{name}
#
# init script
%if %{with systemd}
%{__install} -D -m 644 %{S:3} %{buildroot}/usr/lib/tmpfiles.d/%{name}.conf
%{__ln_s} -f %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}
install -D -m 0644 %{S:2} %{buildroot}%{_unitdir}/%{name}.service
%else
%{__install} -D -m 0755 %{S:1} %{buildroot}%{_sysconfdir}/init.d/%{name}
%{__ln_s} -f %{_sysconfdir}/init.d/%{name} %{buildroot}%{_sbindir}/rc%{name}
%endif
#
touch -m 0640 %{buildroot}%{_var}/log/%{name}/%{name}.log
%{__install} -D -m 644 %{S:4} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}

%check
make test

%clean
rm -rf %{buildroot}

%pre
/usr/sbin/groupadd   -r %{pkg_group} &>/dev/null || :
/usr/sbin/useradd -g %{pkg_group} -s /bin/false -r -c "pgbouncer User" -d %{pkg_home} %{pkg_user} &>/dev/null || :
%if %{with systemd}
%service_add_pre %{name}.service
%endif

%preun
%if %{with systemd}
%service_del_preun %{name}.service
%else
%stop_on_removal %{name}
%endif

%post
%if %{with systemd}
systemd-tmpfiles --create /usr/lib/tmpfiles.d/%{name}.conf || true
%service_add_post %{name}.service
%else
%fillup_only %{name}
%endif

%postun
%if %{with systemd}
%service_del_postun %{name}.service
%else
%restart_on_update %{name}
%insserv_cleanup
%endif


%files
%defattr(-,root,root,-)
%{_sbindir}/pgbouncer
%{_mandir}/man1/pgbouncer.1*
%{_mandir}/man5/pgbouncer.5*
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%config(noreplace) %attr(-,root,%{pkg_group}) %{_sysconfdir}/%{name}/
%doc %{_defaultdocdir}/%{name}/
#
%if %{with systemd}
/usr/lib/tmpfiles.d/%{name}.conf
%{_unitdir}/%{name}.service
%else
%dir %attr(0750,%{pkg_user},%{pkg_group}) %{pkg_home}
%config %{_sysconfdir}/init.d/%{name}
%endif
%{_sbindir}/rc%{name}
%dir %attr(-,%{pkg_user},%{pkg_group}) %{_var}/log/%{name}
%ghost %attr(-,%{pkg_user},%{pkg_group}) %{_var}/log/%{name}/%{name}.log

%changelog
* Thu Sep  6 2018 Marcus Rueckert <mrueckert@suse.de>
- update to 1.9.0
  - Features
  - RECONNECT command
  - WAIT_CLOSE command
  - Fast close - Disconnect a server in session pool mode
    immediately if it is in “close_needed” (reconnect) mode.
  - Add close_needed column to SHOW SERVERS
  - Fixes
  - Avoid double-free in parse_filename
  - Avoid NULL pointer deref in parse_line
  - Cleanups
  - Port mkauth.py to Python 3
  - Improve signals documentation
  - Improve quick start documentation
  - Document SET command
  - Correct list of required software
  - Fix -Wimplicit-fallthrough warnings
  - Add missing documentation for various SHOW fields
  - Document reconnect behavior on reload and DNS change
  - Document that KILL requires RESUME afterwards
  - Clarify documentation of server_lifetime
  - Typos and capitalization fixes in messages and docs
  - Fix psql invocation in tests
  - Various other test setup improvements
- refreshed just-reopen-logs-signal.patch
* Mon Feb 26 2018 mrueckert@suse.de
- switch to pkgconfig BR for c-ares
* Fri Jan 19 2018 mrueckert@suse.de
- Use signal SIGTTIN for reopening log files so we no longer have
  to reload the whole config for this. We have cases where this
  breaks our running config.
  - added just-reopen-logs-signal.patch
* Thu Dec 21 2017 mrueckert@suse.de
- update to 1.8.1
  Include file include/pam.h into distribution tarball. This
  prevented the 1.8 tarball from building at all.
- drop our copy of pam.h again
* Tue Dec 19 2017 mrueckert@suse.de
- enable pam support (new BR: pam-devel)
* Tue Dec 19 2017 mrueckert@suse.de
- update to 1.8
  - Features
  - Support PAM authentication. (Enable with –with-pam.)
  - Add paused and disabled fields to SHOW DATABASES output.
  - Add maxwait_us field to SHOW POOLS output.
  - Add wait and wait_us fields to SHOW commands output.
  - Add new commands SHOW STATS_TOTALS and SHOW STATS_AVERAGES.
  - Track queries and transactions separately in SHOW STATS. The
    fields total_query_time, avg_query, avg_query, and avg_query
    have been replaced by new fields.
  - Add wait_time to SHOW STATS.
  - Fixes
  - Updated libusual supports OpenSSL 1.1.
  - Do not attempt to use TLS on Unix sockets.
  - When parsing pg_hba.conf, keep parsing after erroneous lines
    instead of rejecting the whole file. (#118)
  - Several other hba parsing fixes.
  - Fix race condition when canceling query. (#141)
  - Cleanups
  - auth_user setting is now also allowed globally, not only per
    database. (#142)
  - Set console client and server encoding to UTF8.
- add include/pam.h as source99 as it is missing in the release
  tarball (gh#pgbouncer/pgbouncer/issues/261)
- drop patches which are included upstream
  0001-tls-do-not-ask-TLS-on-unix-socket.patch
  0002-tls-reject-client-TLS-request-on-unix-socket.patch
  0003-hba-Skip-unparseable-lines-keep-parsing-to-the-end.patch
* Wed Aug  9 2017 mrueckert@suse.de
- add logrotate config and recommends for logrotate
* Thu Jul  7 2016 mrueckert@suse.de
- pull 3 patches from upstream:
  0001-tls-do-not-ask-TLS-on-unix-socket.patch
  0002-tls-reject-client-TLS-request-on-unix-socket.patch
  0003-hba-Skip-unparseable-lines-keep-parsing-to-the-end.patch
- fix service file reload action
* Thu Jul  7 2016 mrueckert@suse.de
- they use methods now that require openssl 1.0
* Mon Apr 25 2016 mrueckert@suse.de
- update to 1.7.2
  all changes inbetween:
  https://pgbouncer.github.io/changelog.html#pgbouncer-17x
  https://pgbouncer.github.io/changelog.html#pgbouncer-16x
  https://pgbouncer.github.io/changelog.html#pgbouncer-15x
* Mon Dec  1 2014 mrueckert@suse.de
- forgot the systemd requires
* Mon Dec  1 2014 mrueckert@suse.de
- add reload support to the systemd file
- set restart=always for the service
* Mon Dec  1 2014 mrueckert@suse.de
- add systemd support
* Tue Jun 18 2013 adam@mizerski.pl
- fixed creation of system user
* Fri Mar  8 2013 darin@darins.net
- Update to 1.5.4
  * DNS: Fix memory leak in getaddrinfo_a() backend.
  * DNS: Fix memory leak in udns backend.
  * DNS: Fix stats calculation.
  * DNS: Improve error message handling for getaddrinfo_a().
  * Fix win32 compile.
  * Fix compiler dependency support check in configure.
  * Few documentation fixes.
* Tue Nov 27 2012 mrueckert@suse.de
- update to 1.5.3: (CVE-2012-4575)
  see /usr/share/doc/packages/pgbouncer/NEWS
- drop pgbouncer-1.4_default_config.patch:
  applied upstream
* Thu Apr 14 2011 mrueckert@suse.de
- revert it, libevent is too old even on sle10
* Thu Apr 14 2011 mrueckert@suse.de
- fix build on older sle versions
* Sat Mar 19 2011 mrueckert@suse.de
- moved binaries to _sbindir
- added init script
- added user and group
- added pgbouncer-1.4_default_config.patch
  change path for pid file and log file
- create log file in %%install for proper permissions
- added logrotate file
* Sat Mar 19 2011 mrueckert@suse.de
- install documentation
- build with verbose to see the compiler cmdlines
* Sat Mar 19 2011 mrueckert@suse.de
- initial package (v1.4)
